@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '0.008000';
+our $VERSION = '0.009000';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -233,7 +233,11 @@ The consumer_tag is returned.  This command does B<not> return AMQP
 frames, it simply notifies RabbitMQ that messages for this queue should
 be delivered down the specified channel.
 
-=head2 recv()
+=head2 recv($timeout)
+
+C<$timeout> is a positive integer, specifying the number of milliseconds to
+wait for a message. If you do not provide a timeout (or set it to 0), then
+this call will block until it receives a message.
 
 This command receives and reconstructs AMQP frames and returns a hash
 containing the following information:
@@ -265,6 +269,9 @@ C<$props> is the hash sent by publish()  respecting the following keys:
        timestamp => $integer,
      }
 
+If you provide a timeout, then the C<recv()> method returns C<undef> if the
+timeout expires before a message is received from the server.
+
 =head2 cancel($channel, $consumer_tag)
 
 C<$channel> is a channel that has been opened with C<channel_open>.
